==> webview_flutter_ext-0.3.26.tar.gz: android/src/main/java/io/flutter/plugins/webviewflutter/VideoViewController.java <==
package io.flutter.plugins.webviewflutter;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.pm.ActivityInfo;
import android.content.res.Resources;
import android.graphics.Color;
import android.media.MediaPlayer;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebChromeClient;
import android.widget.FrameLayout;
import android.widget.ImageButton;
import android.widget.VideoView;

/**
 * Created on 05.26 - 2020
 *
 * @author wenbosheng
 * Copyright (c) 2020 android Amber
 */
public class VideoViewController {

    private FrameLayout mVideoContainer;
    private VideoView videoView;
    private Activity holderActivity;
    private int originalVisibility;
    private int originalOrientation;
    private WebChromeClient.CustomViewCallback customViewCallback;

    public VideoViewController() {
    }

    public void setHolderActivity(Activity holderActivity) {
        this.holderActivity = holderActivity;
    }

    @SuppressLint("SourceLockedOrientationActivity")
    void onShowCustomView(final View view, final WebChromeClient.CustomViewCallback callback) {
        if (view == null) {
            return;
        }
        if (mVideoContainer != null && callback != null) {
            callback.onCustomViewHidden();
            return;
        }
        final Activity activity = holderActivity;
        if (activity == null) {
            return;
        }
        originalOrientation = activity.getRequestedOrientation();
        customViewCallback = callback;
        FrameLayout decorView = (FrameLayout) activity.getWindow().getDecorView();
        Context context = view.getContext();
        mVideoContainer = new FrameLayout(context);
        mVideoContainer.setBackgroundColor(Color.BLACK);
        mVideoContainer.addView(view, new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        ImageButton arrowBackButton = new ImageButton(context);
        arrowBackButton.setImageResource(R.drawable.ic_arrow);
        arrowBackButton.setBackground(null);
        arrowBackButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                onHideCustomView();
            }
        });
        int _16Dp = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP,16, Resources.getSystem().getDisplayMetrics());
        FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.leftMargin = _16Dp;
        params.topMargin = _16Dp/2;
        mVideoContainer.addView(arrowBackButton,params);

        originalVisibility = decorView.getSystemUiVisibility();
        decorView.addView(mVideoContainer, new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        decorView.setSystemUiVisibility(
                View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
                        // Set the content to appear under the system bars so that the
                        // content doesn't resize when the system bars hide and show.
                        | View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                        | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN
                        // Hide the nav bar and status bar
                        | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_FULLSCREEN);

        mVideoContainer.setKeepScreenOn(true);
        if (view instanceof FrameLayout) {
            if (((FrameLayout) view).getFocusedChild() instanceof VideoView) {
                videoView = (VideoView) ((FrameLayout) view).getFocusedChild();
                videoView.setOnErrorListener(new VideoCompletionListener());
                videoView.setOnCompletionListener(new VideoCompletionListener());
            }
        }
        activity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
    }

    void onHideCustomView() {
        final Activity activity = holderActivity;
        if (mVideoContainer!=null){
            mVideoContainer.removeAllViews();
            mVideoContainer.setKeepScreenOn(false);
        }
        if (activity != null) {
            FrameLayout decorView = (FrameLayout) activity.getWindow().getDecorView();
            decorView.removeView(mVideoContainer);
            decorView.setSystemUiVisibility(originalVisibility);
            activity.setRequestedOrientation(originalOrientation);
        }
        mVideoContainer = null;
        if (videoView != null) {
            videoView.setOnErrorListener(null);
            videoView.setOnCompletionListener(null);
            videoView = null;
        }
    }


    private class VideoCompletionListener implements MediaPlayer.OnCompletionListener, MediaPlayer.OnErrorListener {
        @Override
        public boolean onError(MediaPlayer mp, int what, int extra) {
            return false;
        }

        @Override
        public void onCompletion(MediaPlayer mp) {
            onHideCustomView();
        }
    }

}

==> webview_flutter_ext-0.3.27.tar.gz: android/src/main/java/io/flutter/plugins/webviewflutter/VideoViewController.java <==
package io.flutter.plugins.webviewflutter;

import android.annotation.SuppressLint;
import android.app.Activity;
import android.content.Context;
import android.content.pm.ActivityInfo;
import android.content.res.Resources;
import android.graphics.Color;
import android.media.MediaPlayer;
import android.util.Log;
import android.util.TypedValue;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebChromeClient;
import android.widget.FrameLayout;
import android.widget.ImageButton;
import android.widget.VideoView;

/**
 * Created on 05.26 - 2020
 *
 * @author wenbosheng
 * Copyright (c) 2020 android Amber
 */
class VideoViewController {

    private FrameLayout mVideoContainer;
    private VideoView videoView;
    private Activity holderActivity;
    private int originalVisibility;
    private int originalOrientation;
    private WebChromeClient.CustomViewCallback customViewCallback;

    public VideoViewController() {
    }

    public void setHolderActivity(Activity holderActivity) {
        this.holderActivity = holderActivity;
    }

    @SuppressLint("SourceLockedOrientationActivity")
    void onShowCustomView(final View view, final WebChromeClient.CustomViewCallback callback) {
        if (view == null) {
            onHideCustomView();
            return;
        }
        if (mVideoContainer != null && callback != null) {
            onHideCustomView();
            return;
        }
        final Activity activity = holderActivity;
        if (activity == null) {
            onHideCustomView();
            return;
        }
        originalOrientation = activity.getRequestedOrientation();
        customViewCallback = callback;
        FrameLayout decorView = (FrameLayout) activity.getWindow().getDecorView();
        mVideoContainer = new FrameLayout(activity);
        view.setBackgroundColor(Color.BLACK);
        mVideoContainer.setBackgroundColor(Color.BLACK);
        mVideoContainer.addView(view, new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        ImageButton arrowBackButton = new ImageButton(activity);
        arrowBackButton.setImageResource(R.drawable.ic_arrow);
        arrowBackButton.setBackground(null);
        arrowBackButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                onHideCustomView();
            }
        });
        int _16Dp = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP,16, Resources.getSystem().getDisplayMetrics());
        FrameLayout.LayoutParams params = new FrameLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT, ViewGroup.LayoutParams.WRAP_CONTENT);
        params.leftMargin = _16Dp;
        params.topMargin = _16Dp/2;
        mVideoContainer.addView(arrowBackButton,params);
        originalVisibility = decorView.getSystemUiVisibility();
        decorView.addView(mVideoContainer, new FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT));
        decorView.setSystemUiVisibility(
                View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY
                        // Set the content to appear under the system bars so that the
                        // content doesn't resize when the system bars hide and show.
                        | View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                        | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN
                        // Hide the nav bar and status bar
                        | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_FULLSCREEN);

        mVideoContainer.setKeepScreenOn(true);
        if (view instanceof FrameLayout) {
            if (((FrameLayout) view).getFocusedChild() instanceof VideoView) {
                videoView = (VideoView) ((FrameLayout) view).getFocusedChild();
                videoView.setOnErrorListener(new VideoCompletionListener());
                videoView.setOnCompletionListener(new VideoCompletionListener());
            }
        }
        activity.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
    }

    void onHideCustomView() {
        final Activity activity = holderActivity;
        if (mVideoContainer!=null){
            mVideoContainer.removeAllViews();
            mVideoContainer.setKeepScreenOn(false);
        }

        if (activity != null) {
            FrameLayout decorView = (FrameLayout) activity.getWindow().getDecorView();
            decorView.removeView(mVideoContainer);
            decorView.setSystemUiVisibility(originalVisibility);
            activity.setRequestedOrientation(originalOrientation);
        }
        mVideoContainer = null;
        if (videoView != null) {
            videoView.setOnErrorListener(null);
            videoView.setOnCompletionListener(null);
            videoView = null;
        }
        if (customViewCallback!=null){
            customViewCallback.onCustomViewHidden();
        }
    }


    private class VideoCompletionListener implements MediaPlayer.OnCompletionListener, MediaPlayer.OnErrorListener {
        @Override
        public boolean onError(MediaPlayer mp, int what, int extra) {
            Log.i("FlutterWebView","video play error:"+what+",extra = "+extra);
            onHideCustomView();
            return false;
        }

        @Override
        public void onCompletion(MediaPlayer mp) {
            onHideCustomView();
        }
    }

}
